Chapter 5: Bayesian Statistical Inference
-----------------------------------------
This chapter develops the fundamentals of Bayesian statistical inference,
and finishes with some examples of computing statistics in this manner.
